@@ -13,7 +13,7 @@ use Digest::MD5 qw(md5_hex);
 use Errno;
 use Data::Dumper;
 our $AUTOLOAD;
-*VERSION = \'2.2.0.1';
+*VERSION = \'2.3.0.1';
 
 use constant { OK => 0, WARNING => 1, CRITICAL => 2, UNKNOWN => 3 };
 
@@ -131,6 +131,12 @@ sub add_default_args {
    The tertiary name of a component",
       required => 0,
   );
+  $self->add_arg(
+      spec => 'extra-opts=s',
+      help => "--extra-opts
+   read command line arguments from an external file",
+      required => 0,
+  );
   $self->add_arg(
       spec => 'blacklist|b=s',
       help => '--blacklist
@@ -1192,12 +1198,13 @@ sub valdiff {
           if ($date >= ($now - $self->opts->lookback)) {
             $last_values->{$_} = $last_values->{lookback_history}->{$_}->{$date};
             $last_values->{timestamp} = $date;
+            $self->{'delta_timestamp'} = $now - $last_values->{timestamp};
             if (ref($last_values->{$_}) eq "ARRAY") {
               $self->debug(sprintf "oldest value of %s within lookback is size %s (age %d)",
-                  $_, scalar(@{$last_values->{$_}}), time - $date);
+                  $_, scalar(@{$last_values->{$_}}), $now - $date);
             } else {
               $self->debug(sprintf "oldest value of %s within lookback is %s (age %d)",
-                  $_, $last_values->{$_}, time - $date);
+                  $_, $last_values->{$_}, $now - $date);
             }
             last;
           } else {
